OC.L10N.register(
    "core",
    {
    "Please select a file." : "Aukeratu fitxategi bat.",
    "File is too big" : "Fitxategia handiegia da",
    "The selected file is not an image." : "Aukeratutako fitxategia ez da irudi bat.",
    "The selected file cannot be read." : "Aukeratutako fitxategia ezin da irakurri.",
    "The file was uploaded" : "Fitxategia igo da",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Igotako fitxategiak php.ini fitxategiko upload_max_filesize direktiban zehazturikoa gainditzen du",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Igotako fitxategiak HTML formularioan ezarritako MAX_FILE_SIZE direktiban zehazturikoa gainditzen du",
    "The file was only partially uploaded" : "Fitxategia erdizka igo da",
    "No file was uploaded" : "Ez da fitxategirik igo",
    "Missing a temporary folder" : "Aldi baterako karpeta bat falta da",
    "Could not write file to disk" : "Ezin izan da fitxategia diskoan idatzi",
    "A PHP extension stopped the file upload" : "PHP hedapen batek fitxategi igotzea gelditu du",
    "Invalid file provided" : "Baliogabeko fitxategia eman da",
    "No image or file provided" : "Ez da irudi edo fitxategirik eman",
    "Unknown filetype" : "Fitxategi mota ezezaguna",
    "An error occurred. Please contact your admin." : "Errore bat gertatu da, jarri zure administratzailearekin harremanetan.",
    "Invalid image" : "Baliogabeko irudia",
    "No temporary profile picture available, try again" : "Ez dago behin-behineko profil irudirik erabilgarri, saiatu berriro",
    "No crop data provided" : "Ez da mozketa daturik eman",
    "No valid crop data provided" : "Ez da baliozko mozketa daturik eman",
    "Crop is not square" : "Mozketa ez da karratua",
    "State token does not match" : "Egoera-tokena ez dator bat",
    "Invalid app password" : "Aplikazio pasahitz baliogabea",
    "Could not complete login" : "Ezin izan da saioa hasi",
    "State token missing" : "Egoera-tokena falta da",
    "Your login token is invalid or has expired" : "Zure saio-hasierako tokena baliogabea da edo iraungi da",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Nextcloud komunitate bertsio honek ez du laguntza-zerbitzurik eta push jakinarazpenak mugatuak dira.",
    "Login" : "Hasi saioa",
    "Unsupported email length (>255)" : "E-posta luzera onartezina (>255)",
    "Password reset is disabled" : "Pasahitza berrezartzea desgaituta dago",
    "Could not reset password because the token is expired" : "Ezin izan da pasahitza berrezarri tokena iraungi delako",
    "Could not reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
    "Password is too long. Maximum allowed length is 469 characters." : "Pasahitza luzeegia da. Onartzen den maximoa 469 karaktere da.",
    "%s password reset" : "%s pasahitza berrezarrita",
    "Password reset" : "Pasahitza berrezarri",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Egin klik ondoko botoian zure pasahitza berrezartzeko. Ez baduzu pasahitzaren berrezarpena eskatu, ahaztu mezu elektroniko hau.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Egin klik ondoko estekan zure pasahitza berrezartzeko. Ez baduzu pasahitzaren berrezarpena eskatu, ahaztu mezu elektroniko hau.",
    "Reset your password" : "Berrezarri zure pasahitza",
    "The given provider is not available" : "Emandako hornitzailea ez dago erabilgarri",
    "Task not found" : "Ez da eginkizuna aurkitu",
    "Internal error" : "Barne errorea",
    "Not found" : "Ez da aurkitu",
    "Bad request" : "Eskaera txarra",
    "Requested task type does not exist" : "Eskatutako eginkizun mota ez da existitzen",
    "Necessary language model provider is not available" : "Beharrezko lengoaia-modelo hornitzailea ez dago eskuragarri",
    "No text to image provider is available" : "Ez dago testutik irudirako hornitzailerik erabilgarri",
    "Image not found" : "Ez da irudia aurkitu",
    "No translation provider available" : "Ez dago itzulpen-hornitzailerik erabilgarri",
    "Could not detect language" : "Ezin izan da hizkuntza hauteman",
    "Unable to translate" : "Ezin izan da itzuli",
    "Nextcloud Server" : "Nextcloud zerbitzaria",
    "Some of your link shares have been removed" : "Zure esteka partekatzeetako batzuk kendu dira",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Segurtasun errore baten ondorioz zure esteka partekatze batzuk kendu ditugu. Ikusi esteka informazio gehiagorako.",
    "The account limit of this instance is reached." : "Instantzia honen kontuen mugara iritsi da.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Sartu zure harpidetza-gakoa laguntza-aplikazioan kontuen muga handitzeko. Horrek Nextcloud Enterprise-k eskaintzen dituen abantaila gehigarri guztiak ere ematen dizkizu eta oso gomendagarria da enpresetan funtzionatzeko.",
    "Learn more ↗" : "Informazio gehiago ↗",
    "Preparing update" : "Eguneratzea prestatzen",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Konponketa pausoa:",
    "Repair info:" : "Konponketa informazioa:",
    "Repair warning:" : "Konponketa abisua:",
    "Repair error:" : "Konponketa errorea:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Mesedez, erabili komando-lerroko eguneratzailea, arakatzailearen bidez eguneratzea desgaituta dagoelako zure config.php-n.",
    "Turned on maintenance mode" : "Mantentze modua aktibatu da",
    "Turned off maintenance mode" : "Mantentze modua desaktibatu da",
    "Maintenance mode is kept active" : "Mantentze moduak aktibatuta jarraitzen du.",
    "Updating database schema" : "Datu-basearen eskema eguneratzen",
    "Updated database" : "Datu-basea eguneratuta",
    "Update app \"%s\" from App Store" : "Eguneratu \"%s\" aplikazioa aplikazioen dendatik",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s datu-basearen eskema eguneratu daitekeen egiaztatzen (honek luze jo dezake datu-basearen tamainaren arabera)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\" eguneratu da %2$s(e)ra",
    "Set log level to debug" : "Ezarri egunkari-maila arazketara",
    "Reset log level" : "Berrezarri egunkari-maila",
    "Starting code integrity check" : "Kodearen integritate egiaztapena hasten",
    "Finished code integrity check" : "Kodearen integritate egiaztapena bukatuta",
    "%s (incompatible)" : "%s (bateraezina)",
    "The following apps have been disabled: %s" : "Hurrengo aplikazioak desgaitu dira: %s",
    "Already up to date" : "Eguneratuta dago dagoeneko",
    "Error occurred while checking server setup" : "Errorea gertatu da zerbitzariaren konfigurazioa egiaztatzean",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Xehetasun gehiago lortzeko, ikusi {linkstart}dokumentazioa ↗{linkend}.",
    "unknown text" : "testu ezezaguna",
    "Hello world!" : "Kaixo mundua!",
    "sunny" : "eguzkitsua",
    "Hello {name}, the weather is {weather}" : "Kaixo {name}, eguraldia {weather} da",
    "Hello {name}" : "Kaixo {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Hauek dira zure bilaketaren emaitzak:<script>alert(1)</script></strong>",
    "new" : "berria",
    "_download %n file_::_download %n files_" : ["deskargatu fitxategi %n","deskargatu %n fitxategi"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Eguneratzea abian da, orri hau utziz gero prozesua eten liteke ingurune batzuetan.",
    "Update to {version}" : "Eguneratu {version} bertsiora",
    "An error occurred." : "Errore bat gertatu da.",
    "Please reload the page." : "Mesedez birkargatu orria.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Eguneraketak huts egin du. Informazio gehiagorako begiratu <a href=\"{url}\">gure foroko argitalpena</a> arazo honi buruz.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Eguneraketak huts egin du. Mesedez, jakinarazi arazoa <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud komunitateari</a>.",
    "Continue to {productName}" : "Jarraitu hona: {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Eguneraketa behar bezala egin da. {productName} ra birbideratuko zaitugu %nsegundotan.","Eguneraketa behar bezala egin da. {productName} (e)ra birbideratuko zaitugu %n segundotan."],
    "Applications menu" : "Aplikazio-menua",
    "Apps" : "Aplikazioak",
    "More apps" : "Aplikazio gehiago",
    "_{count} notification_::_{count} notifications_" : ["Jakinarazpen {count}","{count} jakinarazpenak"],
    "No" : "Ez",
    "Yes" : "Bai",
    "The remote URL must include the user." : "Urruneko URLak erabiltzailea eduki behar du.",
    "Invalid remote URL." : "Urruneko URL baliogabea",
    "Failed to add the public link to your Nextcloud" : "Huts egin du esteka publikoa zure Nextcloudera gehitzean",
    "Federated user" : "Erabiltzaile federatua",
    "user@your-nextcloud.org" : "erabiltzaile@zure-nextcloud.org",
    "Create share" : "Sortu partekatzea",
    "Direct link copied to clipboard" : "Esteka zuzena arbelera kopiatuta",
    "Please copy the link manually:" : "Mesedez kopiatu esteka eskuz:",
    "Custom date range" : "Data-tarte pertsonalizatua",
    "Pick start date" : "Aukeratu hasiera-data",
    "Pick end date" : "Aukeratu amaiera-data",
    "Search in date range" : "Bilatu data-tartean",
    "Search in current app" : "Bilatu aplikazio honetan",
    "Clear search" : "Garbitu bilaketa",
    "Search everywhere" : "Bilatu nonahi",
    "Searching …" : "Bilatzen…",
    "Start typing to search" : "Hasi idazten bilatzeko",
    "No matching results" : "Ez dago bilaketaren emaitzarik",
    "Today" : "Gaur",
    "Last 7 days" : "Azken 7 egunetan",
    "Last 30 days" : "Azken 30 egunetan",
    "This year" : "Urte honetan",
    "Last year" : "Azken urtea",
    "Unified search" : "Bilaketa bateratua",
    "Search apps, files, tags, messages" : "Bilatu aplikazioak, fitxategiak, etiketak, mezuak",
    "Places" : "Lekuak",
    "Date" : "Data",
    "Search people" : "Bilatu pertsonak",
    "People" : "Jendea",
    "Filter in current view" : "Iragazi uneko ikuspegian",
    "Results" : "Emaitzak",
    "Load more results" : "Kargatu emaitza gehiago ",
    "Search in" : "Bilatu hemen",
    "Log in" : "Hasi saioa",
    "Logging in …" : "Saioa hasten...",
    "Log in to {productName}" : "Hasi saioa {productName}-(e)n",
    "Wrong login or password." : "Erabiltzaile edo pasahitz okerra.",
    "This account is disabled" : "Kontu hau desgaituta dago",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Saioa hasteko hainbat saiakera baliogabe jaso ditugu zure IPtik. Ondorioz, zure hurrengo saio hasiera 30 segundo atzeratuko da.",
    "Account name or email" : "Kontu izena edo posta elektronikoa",
    "Account name" : "Kontuaren izena",
    "Server side authentication failed!" : "Zerbitzari aldeko autentifikazioak huts egin du!",
    "Please contact your administrator." : "Mesedez jarri harremanetan zure administratzailearekin.",
    "Temporary error" : "Aldi baterako errorea",
    "Please try again." : "Mesedez saiatu berriro.",
    "An internal error occurred." : "Barne-errore bat gertatu da.",
    "Please try again or contact your administrator." : "Saiatu berriro edo jarri harremanetan zure administratzailearekin.",
    "Password" : "Pasahitza",
    "Log in with a device" : "Hasi saioa gailu batekin",
    "Login or email" : "Erabiltzaile-izen edo e-posta",
    "Your account is not setup for passwordless login." : "Zure kontua ez dago pasahitzik gabeko autentifikaziorako konfiguratua.",
    "Your connection is not secure" : "Zure konexioa ez da segurua",
    "Passwordless authentication is only available over a secure connection." : "Pasahitzik gabeko autentifikazioa konexio seguruetan erabil daiteke soilik.",
    "Browser not supported" : "Ez da nabigatzailea onartzen",
    "Passwordless authentication is not supported in your browser." : "Zure nabigatzaileak ez du pasahitzik gabeko autentifikaziorik onartzen.",
    "Reset password" : "Berrezarri pasahitza",
    "Back to login" : "Itzuli saio hasierara",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Kontu hau badago, pasahitza berrezartzeko mezua bidali da bere helbide elektronikora. Jasotzen ez baduzu, egiaztatu zure helbide elektronikoa eta/edo kontuaren izena, egiaztatu spam/zabor-karpetak edo eskatu laguntza administrazio lokalari.",
    "Couldn't send reset email. Please contact your administrator." : "Ezin izan da berrezartzeko e-posta bidali. Jarri zure administratzailearekin harremanetan.",
    "Password cannot be changed. Please contact your administrator." : "Ezin da pasahitza aldatu. Jarri harremanetan zure administratzailearekin.",
    "New password" : "Pasahitz berria",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Zure fitxategiak enkriptatuta daude. Pasahitza berrezarri ondoren ezin izango dituzu zure datuak berreskuratu. Ez bazaude ziur, galdetu zure administratzaileari jarraitu aurretik. Ziur zaude jarraitu nahi duzula?",
    "I know what I'm doing" : "Badakit zertan ari naizen",
    "Resetting password" : "Pasahitza berrezartzen",
    "Schedule work & meetings, synced with all your devices." : "Antolatu lana eta bilerak, zure gailu guztiekin sinkronizatuta.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Eduki zure lankide eta lagun guztiak leku bakarrean, beren informazioa pribatu mantenduz.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Fitxategiak, Kontaktuak eta Egutegiarekin integratutako posta elektronikoko aplikazio soila.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Txata, bideo-deiak, pantaila partekatzea, lineako bilerak eta web konferentziak - zure nabigatzailean eta mugikorrerako aplikazioekin.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumentu, kalkulu-orri eta aurkezpen kolaboratiboak, Collabora Online-en sortuak.",
    "Distraction free note taking app." : "Distrakziorik gabeko oharrak hartzeko aplikazioa.",
    "Recommended apps" : "Gomendatutako aplikazioak",
    "Loading apps …" : "Aplikazioak kargatzen...",
    "Could not fetch list of apps from the App Store." : "Ezin izan da aplikazioen zerrenda eskuratu aplikazioen dendatik.",
    "App download or installation failed" : "Huts egin du aplikazioaren deskarga edo instalazioak",
    "Cannot install this app because it is not compatible" : "Ezin da aplikazio hau instalatu ez delako bateragarria",
    "Cannot install this app" : "Ezin da aplikazio hau instalatu",
    "Skip" : "Saltatu",
    "Installing apps …" : "Aplikazioak instalatzen...",
    "Install recommended apps" : "Instalatu gomendatutako aplikazioak",
    "Avatar of {displayName}" : "{displayName}-(r)en avatarra",
    "Settings menu" : "Ezarpenen menua",
    "Loading your contacts …" : "Zure kontaktuak kargatzen...",
    "Looking for {term} …" : "{term} bilatzen...",
    "Search contacts" : "Bilatu kontaktuak",
    "Reset search" : "Berrezarri bilaketa",
    "Search contacts …" : "Bilatu kontaktuak...",
    "Could not load your contacts" : "Ezin izan dira zure kontaktuak kargatu",
    "No contacts found" : "Ez da kontakturik aurkitu",
    "Show all contacts" : "Erakutsi kontaktu guztiak",
    "Install the Contacts app" : "Instalatu kontaktuen aplikazioa",
    "Search" : "Bilatu",
    "No results for {query}" : " {query}-(r)entzako emaitzarik ez",
    "Press Enter to start searching" : "Sakatu enter bilaketa hasteko",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Sartu karaktere {minSearchLength} edo gehiago bilatzeko","Sartu {minSearchLength} karaktere edo gehiago bilatzeko"],
    "An error occurred while searching for {type}" : "Errorea gertatu da {type} bilatzean",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Bilaketa idazten hasten zarenean hasten da eta emaitzak gezi-teklen bidez lor daitezke",
    "Search for {name} only" : "Biatu {name} bakarrik",
    "Loading more results …" : "Emaitza gehiago kargatzen ...",
    "Forgot password?" : "Pasahitza ahaztu duzu?",
    "Back to login form" : "Itzuli saio hasierara",
    "Back" : "Atzera",
    "Login form is disabled." : "Saioa hasteko inprimakia desgaituta dago.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud saioa hasteko inprimakia desgaituta dago. Erabili saioa hasteko beste aukera eskuragarri badago edo jarri harremanetan zure administrazioarekin.",
    "More actions" : "Ekintza gehiago",
    "Security warning" : "Segurtasun abisua",
    "Storage & database" : "Biltegia eta datu-basea",
    "Data folder" : "Datuen karpeta",
    "Install and activate additional PHP modules to choose other database types." : "Instalatu eta aktibatu PHP modulu osagarriak, beste datu-base mota batzuk aukeratzeko.",
    "For more details check out the documentation." : "Xehetasun gehiago nahi izanez gero, begiratu dokumentazioa.",
    "Performance warning" : "Errendimendu abisua",
    "You chose SQLite as database." : "SQLite hautatu duzu datu-base gisa.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite garapenerako eta instantzia txikietarako soilik erabili behar litzateke. Produkziorako beste datu-base sistema bat erabiltzea gomendatzen dugu.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Fitxategiak sinkronizatzeko bezeroak erabiltzen badituzu, SQLite ez da batere gomendagarria.",
    "Database user" : "Datu-basearen erabiltzailea",
    "Database password" : "Datu-basearen pasahitza",
    "Database name" : "Datu-basearen izena",
    "Database tablespace" : "Datu-basearen taula-lekua",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zehaztu ataka, makinaren izenarekin batera (adb. localhost:5432).",
    "Database host" : "Datu-basearen ostalaria",
    "Installing …" : "Instalatzen ...",
    "Install" : "Instalatu",
    "Need help?" : "Laguntza behar duzu?",
    "See the documentation" : "Ikusi dokumentazioa",
    "{name} version {version} and above" : "{name} {version} bertsioa eta hortik gorakoak",
    "This browser is not supported" : "Nabigatzaile hau ez da onartzen",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Zure nabigatzailea ez da onartzen. Mesedez, eguneratu bertsio berriago batera edo onartzen den batera.",
    "Continue with this unsupported browser" : "Jarraitu onartzen ez den arakatzaile honekin",
    "Supported versions" : "Onartutako bertsioak",
    "Search {types} …" : "Bilatu  {types} …",
    "Choose {file}" : "Aukeratu {file}",
    "Choose" : "Aukeratu",
    "Copy to {target}" : "Kopiatu hona: {target}",
    "Copy" : "Kopiatu",
    "Move to {target}" : "Mugitu hona: {target}",
    "Move" : "Mugitu",
    "OK" : "Ados",
    "read-only" : "irakurtzeko soilik",
    "_{count} file conflict_::_{count} file conflicts_" : ["fitxategi-gatazka {count}","{count} fitxategi-gatazka"],
    "One file conflict" : "Fitxategi-gatazka bat",
    "New Files" : "Fitxategi berriak",
    "Already existing files" : "Dagoeneko existitzen diren fitxategiak",
    "Which files do you want to keep?" : "Ze fitxategi mantendu nahi dituzu?",
    "If you select both versions, the copied file will have a number added to its name." : "Bi bertsioak hautatzen badituzu, kopiatutako fitxategiaren izenari zenbaki bat gehituko zaio.",
    "Cancel" : "Ezeztatu",
    "Continue" : "Jarraitu",
    "(all selected)" : "(denak hautatuta)",
    "({count} selected)" : "({count} hautatuta)",
    "Error loading file exists template" : "Errorea fitxategia existitzen da txantiloia kargatzean",
    "Saving …" : "Gordetzen …",
    "seconds ago" : "segundo lehenago",
    "Connection to server lost" : "Zerbitzariarekiko konexioa eten da",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Arazoa orria kargatzerakoan, segundo %n barru berriz kargatuko da","Arazoa orria kargatzerakoan,  %n segundo barru berriz kargatuko da"],
    "Add to a project" : "Gehitu proiektu batera",
    "Show details" : "Erakutsi xehetasunak",
    "Hide details" : "Ezkutatu xehetasunak",
    "Rename project" : "Aldatu izena proiektuari",
    "Failed to rename the project" : "Huts egin du proiektuari izena aldatzean",
    "Failed to create a project" : "Huts egin du proiektu bat sortzean",
    "Failed to add the item to the project" : "Elementua proiektura gehitzeak huts egin du",
    "Connect items to a project to make them easier to find" : "Konektatu elementuak proiektu bati aurkitzen errazagoak izan daitezen",
    "Type to search for existing projects" : "Hasi idazten, dauden proiektuak bilatzeko",
    "New in" : "Berria hemen:",
    "View changelog" : "Ikusi aldaketen egunkaria",
    "No action available" : "Ez dago ekintzarik eskuragarri",
    "Error fetching contact actions" : "Errorea kontaktu-ekintzak eskuratzean",
    "Close \"{dialogTitle}\" dialog" : "Itxi \"{dialogTitle}\" elkarrizketa",
    "Email length is at max (255)" : "Posta elektronikoaren luzera gehienez (255) da",
    "Non-existing tag #{tag}" : "#{tag} ez da existitzen",
    "Restricted" : "Mugatua",
    "Invisible" : "Ikusezina",
    "Delete" : "Ezabatu",
    "Rename" : "Berrizendatu",
    "Collaborative tags" : "Elkarlaneko etiketak",
    "No tags found" : "Ez da etiketarik aurkitu",
    "Clipboard not available, please copy manually" : "Arbela ez dago eskuragarri, mesedez kopiatu eskuz",
    "Personal" : "Pertsonala",
    "Accounts" : "Kontuak",
    "Admin" : "Admin",
    "Help" : "Laguntza",
    "Access forbidden" : "Sarrera debekatuta",
    "Page not found" : "Orria ez da aurkitu",
    "The page could not be found on the server or you may not be allowed to view it." : "Ezin izan da orria aurkitu edo ez duzu ikusteko baimenik.",
    "Back to %s" : "Itzuli %s(e)ra",
    "Too many requests" : "Eskaera gehiegi",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Eskaera gehiegi zeuden zure saretik. Saiatu beranduago edo kontaktatu zure administrailearekin hau errorea bada.",
    "Error" : "Errorea",
    "Internal Server Error" : "Zerbitzariaren barne-errorea",
    "The server was unable to complete your request." : "Zerbitzariak ezin izan du zure eskaera bete.",
    "If this happens again, please send the technical details below to the server administrator." : "Hau berriro gertatzen bada, mesedez bidali ondoko datu teknikoak zure administratzaileari.",
    "More details can be found in the server log." : "Xehetasun gehiago zerbitzariaren egunkarian aurki daitezke.",
    "For more details see the documentation ↗." : "Xehetasun gehiagorako, ikusi dokumentazioa ↗.",
    "Technical details" : "Xehetasun teknikoak",
    "Remote Address: %s" : "Urruneko helbidea: %s",
    "Request ID: %s" : "Eskariaren IDa: %s",
    "Type: %s" : "Mota: %s",
    "Code: %s" : "Kodea: %s",
    "Message: %s" : "Mezua: %s",
    "File: %s" : "Fitxategia: %s",
    "Line: %s" : "Lerroa: %s",
    "Trace" : "Aztarna",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Badirudi zure Nextcloud berrinstalatu nahian ari zarela. Hala ere CAN_INSTALL fitxategia falta da zure config direktorioan. Mesedez sor ezazu CAN_INSTALL fitxategia zure config karpetan jarraitu ahal izateko.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ezin izan da CAN_INSTALL fitxategia config karpetatik ezabatu. Mesedez ezaba ezazu fitxategi hau eskuz.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikazio honek JavaScript eskatzen du ondo funtzionatzeko. Mesedez {linkstart}JavaScript gaitu{linkend} eta webgunea birkargatu.",
    "Skip to main content" : "Salto eduki nagusira",
    "Skip to navigation of app" : "Salto aplikazioaren nabigaziora",
    "Go to %s" : "Joan %s-ra",
    "Get your own free account" : "Eskuratu zure kontu propioa doan",
    "Connect to your account" : "Konektatu zure kontura",
    "Please log in before granting %1$s access to your %2$s account." : "Hasi saioa %1$s-(r)i  zure %2$s kontura sarbidea eman aurretik.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Gailu edo aplikazio berri bat konfiguratzen saiatzen ari ez bazara, norbait zu engainatzen saiatzen ari da zure datuetarako sarbidea eman diezaiozun. Kasu horretan, jarraitu ordez jarri harremanetan sistemaren administratzailearekin.",
    "App password" : "Aplikazioaren pasahitza",
    "Grant access" : "Baimendu sarrera",
    "Alternative log in using app password" : "Saio hasiera alternatiboa aplikazioaren pasahitza erabiliz",
    "Account access" : "Kontuaren sarbidea",
    "Currently logged in as %1$s (%2$s)." : "Une honetan %1$s (%2$s) gisa hasita dago saioa.",
    "You are about to grant %1$s access to your %2$s account." : "%1$s-(r)i  zure %2$s kontura sarbidea ematear zaude.",
    "Account connected" : "Kontua konektatuta",
    "Your client should now be connected!" : "Zure bezeroak konektatua behar luke orain!",
    "You can close this window." : "Leiho hau itxi dezakezu.",
    "Previous" : "Aurrekoa",
    "This share is password-protected" : "Partekatze hau pasahitzez babestua dago.",
    "The password is wrong or expired. Please try again or request a new one." : "Pasahitza oker dago edo iraungita dago. Mesedez, saiatu berriro edo eskatu berri bat.",
    "Please type in your email address to request a temporary password" : "Idatzi zure helbide elektronikoa aldi baterako pasahitza eskatzeko",
    "Email address" : "Helbide elektronikoa",
    "Password sent!" : "Pasahitza bidalita!",
    "You are not authorized to request a password for this share" : "Ez duzu baimenik partekatze honetarako pasahitza eskatzeko",
    "Two-factor authentication" : "Bi faktoreko autentifikazioa",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Segurtasun hobetua gaituta dago zure kontuan. Aukeratu autentifikaziorako bigarren faktore bat:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ezin izan da kargatu zure bi faktoreko autentifikazio metodoetako bat gutxienez. Jarri harremanetan zure administratzailearekin.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Bi faktoreko autentifikazioa aplikatzen da baina ez da konfiguratu zure kontuan. Jarri harremanetan zure administratzailearekin laguntza jasotzeko.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Bi faktoreko autentifikazioa aplikatzen da baina ez da konfiguratu zure kontuan. Jarraitu bi pausoko autentifikazioa konfiguratzeko.",
    "Set up two-factor authentication" : "Konfiguratu bi faktoreko autentifikazioa",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Bi faktoreko autentifikazioa aplikatzen da baina ez da konfiguratu zure kontuan. Erabili zure ordezko kode bat saioa hasteko edo jarri harremanetan zure administratzailearekin laguntza jasotzeko.",
    "Use backup code" : "Erabili babeskopia kodea",
    "Cancel login" : "Ezeztatu saio-hasiera",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Segurtasun hobetua aplikatzen da zure kontuan. Aukeratu hornitzailea konfiguratzeko:",
    "Error while validating your second factor" : "Errorea zure bigarren faktorea balioztatzean",
    "Access through untrusted domain" : "Domeinu ez-fidagarritik sartzen",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Jarri harremanetan zure administratzailearekin. Administratzailea bazara,  editatu \"trusted_domains\" ezarpena config/config.php fitxategian, config.sample.php adibidean bezala.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Hau konfiguratzeko informazio gehiago %1$sdokumentazioan%2$s aurki daiteke.",
    "App update required" : "Aplikazioa eguneratu behar da",
    "%1$s will be updated to version %2$s" : "%1$s eguneratuko da %2$s bertsiora.",
    "The following apps will be updated:" : "Hurrengo aplikazioak eguneratuko dira:",
    "These incompatible apps will be disabled:" : "Aplikazio bateraezin hauek desgaituko dira:",
    "The theme %s has been disabled." : "%s gaia desgaitu da.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ekin aurretik egiazta ezazu datu-basearen, ezarpenen karpetaren eta datuen karpetaren babeskopia egin duzula.",
    "Start update" : "Hasi eguneratzea",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Instalazio handietan denbora-mugak saihesteko, horren ordez ondoko komandoa exekuta dezakezu instalazioko direktoriotik:",
    "Detailed logs" : "Egunkari xehea",
    "Update needed" : "Eguneratzea beharrezkoa da",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Komando-lerroko eguneratzailea erabili mesedez, 50 kontu baino gehiagoko instantzia handia baita zurea.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Laguntzarako, ikusi <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentazioa</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Badakit web bidezko UI-a erabiliz eguneratzea egitean arriskuak daudela, eskaera denboraz-kanpo geratzen bada datuen galera gerta daitekeela, baina babeskopia kopia egin dut eta arazoak egonez gero badakit instantzia leheneratzen.",
    "Upgrade via web on my own risk" : "Web bidezko bertsio-berritzea egin, nire ardurapean.",
    "Maintenance mode" : "Mantentze modua",
    "This %s instance is currently in maintenance mode, which may take a while." : "%s instantzia hau mantentze moduan dago une honetan, honek denbora tarte bat iraun dezake.",
    "This page will refresh itself when the instance is available again." : "Instantzia berriz ere erabilgarri dagoenean orri hau freskatuko da.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Jarri harremanetan zure sistema administratzailearekin mezu honek irauten badu edo ezustean agertu bada.",
    "Currently open" : "Irekita une honetan",
    "Login with username or email" : "Hasi saioa erabiltzaile-izen edo e-postarekin",
    "Login with username" : "Hasi saioa erabiltzaile-izenarekin",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Txata, bideo-deiak, pantaila partekatzea, lineako bilerak eta web konferentziak - zure nabigatzailean eta mugikorrerako aplikazioekin.",
    "You have not added any info yet" : "Oraindik ez duzu informaziorik gehitu",
    "{user} has not added any info yet" : "{user}-(e)k ez du oraindik informaziorik gehitu",
    "Error opening the user status modal, try hard refreshing the page" : "Errorea erabiltzailen egoera leihoa irekitzean, saiatu orria guztiz freskatzen",
    "Edit Profile" : "Editatu profila",
    "The headline and about sections will show up here" : "Izenburua eta 'Niri buruz' atalak hemen agertuko dira",
    "Error loading message template: {error}" : "Errorea mezu txantiloia kargatzean: {error}",
    "Very weak password" : "Pasahitz oso ahula",
    "Weak password" : "Pasahitz ahula",
    "So-so password" : "Hala moduzko pasahitza",
    "Good password" : "Pasahitz ona",
    "Strong password" : "Pasahitz sendoa",
    "Profile not found" : "Profila ez da aurkitu",
    "The profile does not exist." : "Profila ez da existitzen",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Zure datuen karpeta eta fitxategiak interneten bidez eskuragarri egon daitezke .htaccess fitxategia ez delako funtzionatzen ari.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Zerbitzaria behar bezala konfiguratzeari buruzko informazio gehiagorako, mesedez begira ezazu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentazioa</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Sortu administratzaile kontu bat</strong>",
    "New admin account name" : "Administratzaile kontu berriaren izena",
    "New admin password" : "Administratzaile pasahitz berria",
    "Show password" : "Erakutsi pasahitza",
    "Toggle password visibility" : "Txandakatu pasahitzaren ikusgaitasuna",
    "Configure the database" : "Konfiguratu datu-basea",
    "Only %s is available." : "Soilik %s dago eskuragarri.",
    "Database account" : "Datu-basearen kontua"
},
"nplurals=2; plural=(n != 1);");
